Configuration API
===============

The ``config`` module contains configuration settings for the Hydro-Topo Features package.

.. automodule:: hydro_topo_features.config
   :members:
   :undoc-members:
   :show-inheritance:

Project Settings
--------------

- ``PROJECT_NAME``: Name of the project
- ``PROJECT_VERSION``: Version of the package

Directory Structure
----------------

- ``DIRECTORY_STRUCTURE``: Dictionary defining the directory structure for outputs

DEM Processing
------------

- ``DEM_PROCESSING``: Dictionary with parameters for DEM processing, including stream burning depth, nodata values, etc.

Feature Parameters
----------------

- ``FEATURE_PARAMS``: Dictionary with parameters for computing HAND, slope, and EDTW

Visualization Settings
-------------------

- ``RASTER_VIS``: Dictionary with settings for visualizing different rasters 